Angrist-Krueger (AK) dataset is a data extract from US Censuses that was analyzed in Angrist and Krueger (1991). In particular, the current dataset is from the 1970 Census, consisting of men born 1920-1929 (Year 1929 is the omitted cohort group).
AKA data frame with 247,199 rows and 42 variables:
Outcome: log weekly wages
Covariate of interest: years of education
Indicator variable for the year of birth: equals 1 if yob = 1920
Indicator variable for the year of birth: equals 1 if yob = 1921
Indicator variable for the year of birth: equals 1 if yob = 1922
Indicator variable for the year of birth: equals 1 if yob = 1923
Indicator variable for the year of birth: equals 1 if yob = 1924
Indicator variable for the year of birth: equals 1 if yob = 1925
Indicator variable for the year of birth: equals 1 if yob = 1926
Indicator variable for the year of birth: equals 1 if yob = 1927
Indicator variable for the year of birth: equals 1 if yob = 1928
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Quarter-of-birth indicator interacted with year-of-birth indicator
Constant
Angrist, J.D. and Krueger, A.B., 1991. Does compulsory school attendance affect schooling and earnings? Quarterly Journal of Economics, 106(4), pp.979--1014. tools:::Rd_expr_doi("10.2307/2937954")